#[non_exhaustive]pub struct ConvertStats {
pub tensors: usize,
pub dequantized: usize,
pub quantized: usize,
pub passthrough: usize,
}Expand description
What a convert call produced, for progress reporting.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tensors: usizeTotal tensors written.
dequantized: usizeInput tensors that were dequantised on the way in, into
ConvertOptions::output_dtype (BF16 by default).
quantized: usizeTensors the target quantised on the way out (the BnB-NF4 encoder).
passthrough: usizeTensors written in their incoming dtype.